geowatch.cli.experimental.find\_recent\_checkpoint module
=========================================================

.. automodule:: geowatch.cli.experimental.find_recent_checkpoint
   :members:
   :undoc-members:
   :show-inheritance:
